sync_stream

Function sync_stream 

pub unsafe fn sync_stream(stream: cudaStream_t) -> Result<(), CudaError>
Synchronize the given explicit CUDA stream, blocking until all previously enqueued work on stream has completed.

Safety

The caller must ensure that stream is a valid CUDA stream handle.